Structs
- Array
Value - Owned Array Container.
- BitVec
Value - Owned bit-vector value. Note: Ord does not necessarily order by value.
- BitVec
Value Index - Index of a bit-vector value in a shared value store.
- BitVec
Value MutRef - BitVec
Value Ref - Bit-vector value that does not own its storage.
- Parse
IntError - Sparse
Array Value - Value
Interner - Ensures that each bit vector value gets a unique index. And each combination of value and width will get a unique BitVecValueIndex
Enums
- Value
- Wraps either an array or a bit vector value.
Constants
Traits
- Array
MutOps - Operations implemented by mutable array values with a dense representation.
- Array
Ops - Operations implemented by read-only array values with a dense representation.
- BitVec
MutOps - Operations over mutable bit-vector values.
- BitVec
Ops - Operations over immutable bit-vector values.
- Index
ToMut Ref - Implemented by value stores to convert indices into mutable value references.
- Index
ToRef - Implemented by a value stores to convert indices into value references.
Functions
Type Aliases
- Double
Word - Width
Int - This type restricts the maximum width that a bit-vector type is allowed to have.
- Word
- Word size for values.